==> atlasq-0.0.3.tar.gz: atlasq-0.0.3/atlasq/queryset/node.py <==
import logging
from typing import Dict, List, Tuple, Union

from mongoengine import Q
from mongoengine.queryset.visitor import QCombination

from atlasq.queryset.visitor import (
    AtlasQueryCompilerVisitor,
    AtlasSimplificationVisitor,
)

logger = logging.getLogger(__name__)


class AtlasQ(Q):
    @property
    def operation(self):
        return self.AND

    def to_query(self, document, use_atlas: bool = False) -> Tuple[Dict, List[Dict]]:
        if not use_atlas:
            return super().to_query(document)
        logger.debug(f"to_query {self.__class__.__name__} {document}")
        query = self.accept(AtlasSimplificationVisitor())
        query = query.accept(AtlasQueryCompilerVisitor(document))
        return query

    def _combine(self, other, operation) -> Union["AtlasQ", "AtlasQCombination"]:
        logger.debug(f"_combine {self.__class__.__name__} {other}, {operation}")

        result = super(AtlasQ, self)._combine(other, operation)
        if isinstance(result, QCombination):
            return AtlasQCombination(result.operation, result.children)
        return AtlasQ(**result.query)


class AtlasQCombination(QCombination):
    def __bool__(self):
        return any(bool(child) for child in self.children)

    def _combine(self, other, operation):
        logger.debug(f"_combine {self.__class__.__name__} {other}, {operation}")
        result = super()._combine(other, operation)
        return AtlasQCombination(result.operation, result.children)

    def to_query(self, document, use_alias: bool = False) -> Tuple[Dict, List[Dict]]:
        if not use_alias:
            return super().to_query(document)
        logger.debug(f"to_query {self.__class__.__name__} {document}")
        query = self.accept(AtlasSimplificationVisitor())
        query = query.accept(AtlasQueryCompilerVisitor(document))
        return query

    def accept(self, visitor):
        logger.debug(f"accept {self.__class__.__name__} {visitor}")
        return super().accept(visitor)

==> atlasq-0.1.1.tar.gz: atlasq-0.1.1/atlasq/queryset/node.py <==
import logging
from typing import Dict, List, Tuple, Union

from mongoengine import Q
from mongoengine.queryset.visitor import QCombination

from atlasq.queryset.visitor import (
    AtlasQueryCompilerVisitor,
    AtlasSimplificationVisitor,
)

logger = logging.getLogger(__name__)


class AtlasQ(Q):
    @property
    def operation(self):
        return self.AND

    def to_query(self, document) -> List[Dict]:  # pylint: disable=arguments-differ
        qs = getattr(document, "atlas", None)
        if qs is None:
            raise ValueError("Document must set `atlas` to an AtlasManager")
        atlas_index = qs.index
        logger.debug(f"to_query {self.__class__.__name__} {document}")
        query = self.accept(AtlasSimplificationVisitor())
        query = query.accept(AtlasQueryCompilerVisitor(document, atlas_index))
        return query

    def _combine(self, other, operation) -> Union["AtlasQ", "AtlasQCombination"]:
        logger.debug(f"_combine {self.__class__.__name__} {other}, {operation}")

        result = super()._combine(other, operation)
        if isinstance(result, QCombination):
            return AtlasQCombination(result.operation, result.children)
        return AtlasQ(**result.query)


class AtlasQCombination(QCombination):
    def __bool__(self):
        return any(bool(child) for child in self.children)

    def _combine(self, other, operation):
        logger.debug(f"_combine {self.__class__.__name__} {other}, {operation}")
        result = super()._combine(other, operation)
        return AtlasQCombination(result.operation, result.children)

    def to_query(  # pylint: disable=arguments-differ
        self, document
    ) -> Tuple[Dict, List[Dict]]:
        qs = getattr(document, "atlas", None)
        if qs is None:
            raise ValueError("Document must set `atlas` to an AtlasManager")
        atlas_index = qs.index
        logger.debug(f"to_query {self.__class__.__name__} {document}")
        query = self.accept(AtlasSimplificationVisitor())
        query = query.accept(AtlasQueryCompilerVisitor(document, atlas_index))
        return query

    def accept(self, visitor):
        logger.debug(f"accept {self.__class__.__name__} {visitor}")
        return super().accept(visitor)
